# Callbacks

::: slurm.callbacks.BaseCallback

::: slurm.callbacks.LoggerCallback

::: slurm.callbacks.RichLoggerCallback

::: slurm.callbacks.BenchmarkCallback

::: slurm.callbacks.WorkflowCallbackContext

::: slurm.callbacks.WorkflowTaskSubmitContext
